pub struct MapToPointDebug {
pub u_bytes: [u8; 32],
}Expand description
Instruction.
Fields
u_bytes: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for MapToPointDebug
impl BorshDeserialize for MapToPointDebug
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MapToPointDebug
impl BorshSerialize for MapToPointDebug
Sourceimpl Discriminator for MapToPointDebug
impl Discriminator for MapToPointDebug
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for MapToPointDebug
impl InstructionData for MapToPointDebug