pub struct UpdateConfig {
pub pubkey_g2: [u8; 128],
pub genesis_time: u64,
pub period: u64,
pub chain_hash: [u8; 32],
}Expand description
Instruction.
Fields
pubkey_g2: [u8; 128]genesis_time: u64period: u64chain_hash: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for UpdateConfig
impl BorshDeserialize for UpdateConfig
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateConfig
impl BorshSerialize for UpdateConfig
Sourceimpl Discriminator for UpdateConfig
impl Discriminator for UpdateConfig
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for UpdateConfig
impl InstructionData for UpdateConfig