pub struct Verify {
pub round: u64,
pub signature: [u8; 64],
}Expand description
Instruction.
Fields
round: u64signature: [u8; 64]Trait Implementations
Sourceimpl BorshDeserialize for Verify
impl BorshDeserialize for Verify
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Verify
impl BorshSerialize for Verify
Sourceimpl Discriminator for Verify
impl Discriminator for Verify
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for Verify
impl InstructionData for Verify