pub struct UpdateConfig<'info> {
pub config: Account<'info, Config>,
pub authority: Signer<'info>,
}Expand description
Accounts for the update_config instruction.
has_one = authority is the authorization primitive — Anchor emits
ConstraintHasOne (error code 2001) automatically if the signer does
not match config.authority. NO custom Unauthorized variant exists
(T1.06 consolidation; see program/spec.md "Error Codes").
bump = config.bump uses the stored canonical bump instead of
re-deriving (≈10K CU saving per ADR 0028).
Fields
config: Account<'info, Config>Trait Implementations
Sourceimpl<'info> Accounts<'info, UpdateConfigBumps> for UpdateConfig<'info>where
'info: 'info,
impl<'info> Accounts<'info, UpdateConfigBumps> for UpdateConfig<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut UpdateConfigBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut UpdateConfigBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl<'info> AccountsExit<'info> for UpdateConfig<'info>where
'info: 'info,
impl<'info> AccountsExit<'info> for UpdateConfig<'info>where
'info: 'info,
Sourceimpl<'info> Bumps for UpdateConfig<'info>where
'info: 'info,
impl<'info> Bumps for UpdateConfig<'info>where
'info: 'info,
Sourcetype Bumps = UpdateConfigBumps
type Bumps = UpdateConfigBumps
Struct to hold account bump seeds.
Sourceimpl<'info> ToAccountInfos<'info> for UpdateConfig<'info>where
'info: 'info,
impl<'info> ToAccountInfos<'info> for UpdateConfig<'info>where
'info: 'info,
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for UpdateConfig<'info>
impl<'info> ToAccountMetas for UpdateConfig<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> Freeze for UpdateConfig<'info>
impl<'info> !RefUnwindSafe for UpdateConfig<'info>
impl<'info> !Send for UpdateConfig<'info>
impl<'info> !Sync for UpdateConfig<'info>
impl<'info> Unpin for UpdateConfig<'info>
impl<'info> UnsafeUnpin for UpdateConfig<'info>
impl<'info> !UnwindSafe for UpdateConfig<'info>